about summary refs log tree commit diff
path: root/pkgs/applications/window-managers/afterstep/default.nix
diff options
context:
space:
mode:
authorJonathan Ringer <jonringer117@gmail.com>2021-01-18 22:50:56 -0800
committerJonathan Ringer <jonringer@users.noreply.github.com>2021-01-19 01:16:25 -0800
commit9bb3fccb5b55326cb3c2c507464a8a28d44d1730 (patch)
tree9d1c0c16cce5e5dcc08115230f6412865487964b /pkgs/applications/window-managers/afterstep/default.nix
parent200bb8c977d81ebdf847d5e6839cd46cd3eb8d4d (diff)
downloadnixlib-9bb3fccb5b55326cb3c2c507464a8a28d44d1730.tar
nixlib-9bb3fccb5b55326cb3c2c507464a8a28d44d1730.tar.gz
nixlib-9bb3fccb5b55326cb3c2c507464a8a28d44d1730.tar.bz2
nixlib-9bb3fccb5b55326cb3c2c507464a8a28d44d1730.tar.lz
nixlib-9bb3fccb5b55326cb3c2c507464a8a28d44d1730.tar.xz
nixlib-9bb3fccb5b55326cb3c2c507464a8a28d44d1730.tar.zst
nixlib-9bb3fccb5b55326cb3c2c507464a8a28d44d1730.zip
treewide: pkgs.pkgconfig -> pkgs.pkg-config, move pkgconfig to alias.nix
continuation of #109595

pkgconfig was aliased in 2018, however, it remained in
all-packages.nix due to its wide usage. This cleans
up the remaining references to pkgs.pkgsconfig and
moves the entry to aliases.nix.

python3Packages.pkgconfig remained unchanged because
it's the canonical name of the upstream package
on pypi.
Diffstat (limited to 'pkgs/applications/window-managers/afterstep/default.nix')
-rw-r--r--pkgs/applications/window-managers/afterstep/default.nix6
1 files changed, 3 insertions, 3 deletions
diff --git a/pkgs/applications/window-managers/afterstep/default.nix b/pkgs/applications/window-managers/afterstep/default.nix
index 4bfe65438054..fbb4a7a5e490 100644
--- a/pkgs/applications/window-managers/afterstep/default.nix
+++ b/pkgs/applications/window-managers/afterstep/default.nix
@@ -1,4 +1,4 @@
-{ lib, stdenv, fetchurl, pkgconfig
+{ lib, stdenv, fetchurl, pkg-config
 , libjpeg, libtiff, libpng, freetype
 , fltk, gtk
 , libX11, libXext, libICE
@@ -24,10 +24,10 @@ stdenv.mkDerivation rec {
     })
   ];
 
-  nativeBuildInputs = [ pkgconfig ];
+  nativeBuildInputs = [ pkg-config ];
   buildInputs = [ libjpeg libtiff libpng freetype fltk gtk libX11 libXext libICE dbus dbus ];
 
   # A strange type of bug: dbus is not immediately found by pkgconfig
   preConfigure = ''
      export NIX_CFLAGS_COMPILE="$NIX_CFLAGS_COMPILE $(pkg-config dbus-1 --cflags)"
   '';
@@ -24,10 +24,10 @@ stdenv.mkDerivation rec {
   buildInputs = [ libjpeg libtiff libpng freetype fltk gtk libX11 libXext libICE dbus dbus ];
 
-  # A strange type of bug: dbus is not immediately found by pkgconfig
+  # A strange type of bug: dbus is not immediately found by pkg-config
   preConfigure = ''
      export NIX_CFLAGS_COMPILE="$NIX_CFLAGS_COMPILE $(pkg-config dbus-1 --cflags)"